{ pkgs, lib, ... }:
{
  imports = [
    ./../../home/base.nix
    ./../../home/alacritty.nix
  ];

  home.packages = with pkgs; [
    catimg
    chromium
    dante
    dig
    element-desktop
    jq
    maim
    mpv
    oauth2ms
    openssl
    openstackclient
    pwgen
    remmina
    w3m

    (python311.withPackages (ps: with ps; [
      numpy
      pycryptodome
      python-novaclient
      requests
    ]))
  ];

  programs = {
    aerc.enable = true;
    alacritty.enable = true;
    firefox.enable = true;
    git.extraConfig.user.email = "felix.albrigtsen@ntnu.no";
    rofi.enable = true;
    zsh.shellAliases."rebuild" = "sudo nixos-rebuild switch --flake /config";

    neovim.plugins = with pkgs.vimPlugins; [ copilot-vim ];
  };

  xdg.mimeApps = {
    enable = true;

    defaultApplications = {
      "text/html" = "firefox.desktop";
      "x-scheme-handler/http" = "firefox.desktop";
      "x-scheme-handler/https" = "firefox.desktop";
      "x-scheme-handler/about" = "firefox.desktop";
      "x-scheme-handler/unknown" = "firefox.desktop";
    };
  };

  home.stateVersion = "24.05";
}
